# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'layout3.ui'
#
# Created by: PyQt5 UI code generator 5.15.4
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(610, 433)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/myIcons/plots.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        MainWindow.setWindowIcon(icon)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.centralwidget)
        self.verticalLayout_4.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_4.setSpacing(0)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.myTabs = QtWidgets.QTabWidget(self.centralwidget)
        self.myTabs.setObjectName("myTabs")
        self.browserTab = QtWidgets.QWidget()
        self.browserTab.setObjectName("browserTab")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.browserTab)
        self.verticalLayout_2.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_2.setSpacing(0)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.webFrame = QtWidgets.QFrame(self.browserTab)
        self.webFrame.setMinimumSize(QtCore.QSize(50, 0))
        self.webFrame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.webFrame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.webFrame.setObjectName("webFrame")
        self.webLayout = QtWidgets.QVBoxLayout(self.webFrame)
        self.webLayout.setContentsMargins(0, 0, 0, 0)
        self.webLayout.setSpacing(0)
        self.webLayout.setObjectName("webLayout")
        self.verticalLayout_2.addWidget(self.webFrame)
        self.myTabs.addTab(self.browserTab, "")
        self.toc = QtWidgets.QWidget()
        self.toc.setObjectName("toc")
        self.experimentListLayout2 = QtWidgets.QVBoxLayout(self.toc)
        self.experimentListLayout2.setContentsMargins(0, 0, 0, 0)
        self.experimentListLayout2.setSpacing(0)
        self.experimentListLayout2.setObjectName("experimentListLayout2")
        self.scrollArea = QtWidgets.QScrollArea(self.toc)
        self.scrollArea.setWidgetResizable(True)
        self.scrollArea.setObjectName("scrollArea")
        self.scrollAreaWidgetContents_2 = QtWidgets.QWidget()
        self.scrollAreaWidgetContents_2.setGeometry(QtCore.QRect(0, 0, 604, 356))
        self.scrollAreaWidgetContents_2.setObjectName("scrollAreaWidgetContents_2")
        self.experimentListLayout = QtWidgets.QVBoxLayout(self.scrollAreaWidgetContents_2)
        self.experimentListLayout.setContentsMargins(0, 0, 0, 0)
        self.experimentListLayout.setSpacing(2)
        self.experimentListLayout.setObjectName("experimentListLayout")
        self.scrollArea.setWidget(self.scrollAreaWidgetContents_2)
        self.experimentListLayout2.addWidget(self.scrollArea)
        self.myTabs.addTab(self.toc, "")
        self.codeTab = QtWidgets.QWidget()
        self.codeTab.setObjectName("codeTab")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.codeTab)
        self.verticalLayout_3.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_3.setSpacing(0)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.codeBrowser = QtWidgets.QTextBrowser(self.codeTab)
        self.codeBrowser.setDocumentTitle("")
        self.codeBrowser.setLineWrapMode(QtWidgets.QTextEdit.NoWrap)
        self.codeBrowser.setObjectName("codeBrowser")
        self.verticalLayout_3.addWidget(self.codeBrowser)
        self.myTabs.addTab(self.codeTab, "")
        self.remoteExptTab = QtWidgets.QWidget()
        self.remoteExptTab.setObjectName("remoteExptTab")
        self.exptLayout = QtWidgets.QVBoxLayout(self.remoteExptTab)
        self.exptLayout.setContentsMargins(0, 0, 0, 0)
        self.exptLayout.setSpacing(0)
        self.exptLayout.setObjectName("exptLayout")
        self.myTabs.addTab(self.remoteExptTab, "")
        self.verticalLayout_4.addWidget(self.myTabs)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 610, 22))
        self.menubar.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.menubar.setObjectName("menubar")
        self.menuTools = QtWidgets.QMenu(self.menubar)
        self.menuTools.setObjectName("menuTools")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.actionLogin_to_Eyes_Online = QtWidgets.QAction(MainWindow)
        self.actionLogin_to_Eyes_Online.setObjectName("actionLogin_to_Eyes_Online")
        self.actionFast_Upload_Graphs = QtWidgets.QAction(MainWindow)
        self.actionFast_Upload_Graphs.setCheckable(True)
        self.actionFast_Upload_Graphs.setObjectName("actionFast_Upload_Graphs")
        self.actionJoin_Room = QtWidgets.QAction(MainWindow)
        self.actionJoin_Room.setObjectName("actionJoin_Room")
        self.actionLeave_Room = QtWidgets.QAction(MainWindow)
        self.actionLeave_Room.setObjectName("actionLeave_Room")
        self.menuTools.addAction(self.actionLogin_to_Eyes_Online)
        self.menuTools.addAction(self.actionFast_Upload_Graphs)
        self.menuTools.addAction(self.actionJoin_Room)
        self.menuTools.addAction(self.actionLeave_Room)
        self.menubar.addAction(self.menuTools.menuAction())

        self.retranslateUi(MainWindow)
        self.myTabs.setCurrentIndex(1)
        self.actionLogin_to_Eyes_Online.triggered.connect(MainWindow.showLoginScreen)
        self.actionFast_Upload_Graphs.toggled['bool'].connect(MainWindow.setAutoGraph)
        self.actionJoin_Room.triggered.connect(MainWindow.showJoinRoom)
        self.actionLeave_Room.triggered.connect(MainWindow.showLeaveRoom)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "CSpark Virtual Labs"))
        self.myTabs.setTabText(self.myTabs.indexOf(self.browserTab), _translate("MainWindow", "Browser"))
        self.myTabs.setTabText(self.myTabs.indexOf(self.toc), _translate("MainWindow", "Experiment List"))
        self.codeBrowser.setPlaceholderText(_translate("MainWindow", "Experiment source codes will be shown here..."))
        self.myTabs.setTabText(self.myTabs.indexOf(self.codeTab), _translate("MainWindow", "Code"))
        self.myTabs.setTabText(self.myTabs.indexOf(self.remoteExptTab), _translate("MainWindow", "Experiment"))
        self.menuTools.setTitle(_translate("MainWindow", "Tools"))
        self.actionLogin_to_Eyes_Online.setText(_translate("MainWindow", "Login to Eyes Online"))
        self.actionFast_Upload_Graphs.setText(_translate("MainWindow", "Fast Upload Graphs"))
        self.actionJoin_Room.setText(_translate("MainWindow", "Join Room"))
        self.actionLeave_Room.setText(_translate("MainWindow", "Leave Room"))
from . import res_rc
