# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'layout3.ui'
#
# Created by: PyQt5 UI code generator 5.14.0
#
# WARNING! All changes made in this file will be lost!


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(610, 433)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.gridLayout = QtWidgets.QGridLayout(self.centralwidget)
        self.gridLayout.setContentsMargins(0, 0, 0, 0)
        self.gridLayout.setSpacing(0)
        self.gridLayout.setObjectName("gridLayout")
        self.myTabs = QtWidgets.QTabWidget(self.centralwidget)
        self.myTabs.setObjectName("myTabs")
        self.toc = QtWidgets.QWidget()
        self.toc.setObjectName("toc")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.toc)
        self.verticalLayout_2.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_2.setSpacing(0)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.webFrame = QtWidgets.QFrame(self.toc)
        self.webFrame.setMinimumSize(QtCore.QSize(50, 0))
        self.webFrame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.webFrame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.webFrame.setObjectName("webFrame")
        self.webLayout = QtWidgets.QVBoxLayout(self.webFrame)
        self.webLayout.setContentsMargins(0, 0, 0, 0)
        self.webLayout.setSpacing(0)
        self.webLayout.setObjectName("webLayout")
        self.verticalLayout_2.addWidget(self.webFrame)
        self.myTabs.addTab(self.toc, "")
        self.experimentTab = QtWidgets.QWidget()
        self.experimentTab.setObjectName("experimentTab")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.experimentTab)
        self.horizontalLayout.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout.setSpacing(0)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.frame = QtWidgets.QFrame(self.experimentTab)
        self.frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame.setObjectName("frame")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.frame)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout.setSpacing(2)
        self.verticalLayout.setObjectName("verticalLayout")
        self.gridLayout_2 = QtWidgets.QGridLayout()
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.myButton = QtWidgets.QPushButton(self.frame)
        self.myButton.setProperty("remote", True)
        self.myButton.setObjectName("myButton")
        self.gridLayout_2.addWidget(self.myButton, 1, 0, 1, 1)
        self.myButton2 = QtWidgets.QPushButton(self.frame)
        self.myButton2.setProperty("remote", True)
        self.myButton2.setObjectName("myButton2")
        self.gridLayout_2.addWidget(self.myButton2, 1, 1, 1, 1)
        self.timeLabel = QtWidgets.QLabel(self.frame)
        self.timeLabel.setObjectName("timeLabel")
        self.gridLayout_2.addWidget(self.timeLabel, 0, 0, 1, 2)
        self.verticalLayout.addLayout(self.gridLayout_2)
        self.mySlider = QtWidgets.QSlider(self.frame)
        self.mySlider.setMaximum(1000)
        self.mySlider.setOrientation(QtCore.Qt.Horizontal)
        self.mySlider.setProperty("remote", True)
        self.mySlider.setObjectName("mySlider")
        self.verticalLayout.addWidget(self.mySlider)
        self.mySlider2 = QtWidgets.QSlider(self.frame)
        self.mySlider2.setOrientation(QtCore.Qt.Horizontal)
        self.mySlider2.setObjectName("mySlider2")
        self.verticalLayout.addWidget(self.mySlider2)
        self.myCombo = QtWidgets.QComboBox(self.frame)
        self.myCombo.setObjectName("myCombo")
        self.verticalLayout.addWidget(self.myCombo)
        self.fr_1 = QtWidgets.QCheckBox(self.frame)
        self.fr_1.setProperty("remote", True)
        self.fr_1.setObjectName("fr_1")
        self.verticalLayout.addWidget(self.fr_1)
        self.fr_2 = QtWidgets.QCheckBox(self.frame)
        self.fr_2.setObjectName("fr_2")
        self.verticalLayout.addWidget(self.fr_2)
        self.fr_3 = QtWidgets.QCheckBox(self.frame)
        self.fr_3.setObjectName("fr_3")
        self.verticalLayout.addWidget(self.fr_3)
        self.fr_4 = QtWidgets.QCheckBox(self.frame)
        self.fr_4.setObjectName("fr_4")
        self.verticalLayout.addWidget(self.fr_4)
        self.fr_5 = QtWidgets.QCheckBox(self.frame)
        self.fr_5.setObjectName("fr_5")
        self.verticalLayout.addWidget(self.fr_5)
        self.fr_6 = QtWidgets.QCheckBox(self.frame)
        self.fr_6.setObjectName("fr_6")
        self.verticalLayout.addWidget(self.fr_6)
        self.fr_7 = QtWidgets.QCheckBox(self.frame)
        self.fr_7.setObjectName("fr_7")
        self.verticalLayout.addWidget(self.fr_7)
        self.fr_8 = QtWidgets.QCheckBox(self.frame)
        self.fr_8.setObjectName("fr_8")
        self.verticalLayout.addWidget(self.fr_8)
        self.horizontalLayout.addWidget(self.frame)
        self.frame_2 = QtWidgets.QFrame(self.experimentTab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame_2.sizePolicy().hasHeightForWidth())
        self.frame_2.setSizePolicy(sizePolicy)
        self.frame_2.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame_2.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_2.setObjectName("frame_2")
        self.plotArea = QtWidgets.QVBoxLayout(self.frame_2)
        self.plotArea.setContentsMargins(2, 2, 2, -1)
        self.plotArea.setSpacing(2)
        self.plotArea.setObjectName("plotArea")
        self.horizontalLayout.addWidget(self.frame_2)
        self.myTabs.addTab(self.experimentTab, "")
        self.code = QtWidgets.QWidget()
        self.code.setObjectName("code")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.code)
        self.verticalLayout_3.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_3.setSpacing(0)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.codeBrowser = QtWidgets.QTextBrowser(self.code)
        self.codeBrowser.setDocumentTitle("")
        self.codeBrowser.setLineWrapMode(QtWidgets.QTextEdit.NoWrap)
        self.codeBrowser.setObjectName("codeBrowser")
        self.verticalLayout_3.addWidget(self.codeBrowser)
        self.myTabs.addTab(self.code, "")
        self.remoteExptTab = QtWidgets.QWidget()
        self.remoteExptTab.setObjectName("remoteExptTab")
        self.exptLayout = QtWidgets.QVBoxLayout(self.remoteExptTab)
        self.exptLayout.setContentsMargins(0, 0, 0, 0)
        self.exptLayout.setSpacing(0)
        self.exptLayout.setObjectName("exptLayout")
        self.myTabs.addTab(self.remoteExptTab, "")
        self.gridLayout.addWidget(self.myTabs, 0, 0, 1, 1)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 610, 22))
        self.menubar.setObjectName("menubar")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)

        self.retranslateUi(MainWindow)
        self.myTabs.setCurrentIndex(0)
        self.myButton.clicked.connect(MainWindow.buttonClicked)
        self.myButton2.clicked.connect(MainWindow.button2Clicked)
        self.mySlider.valueChanged['int'].connect(MainWindow.sliderChanged)
        self.mySlider2.valueChanged['int'].connect(MainWindow.slider2Changed)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "MainWindow"))
        self.myTabs.setTabText(self.myTabs.indexOf(self.toc), _translate("MainWindow", "Contents"))
        self.myButton.setText(_translate("MainWindow", "Button 1"))
        self.myButton2.setText(_translate("MainWindow", "Button 2"))
        self.timeLabel.setText(_translate("MainWindow", "Time Label"))
        self.fr_1.setText(_translate("MainWindow", "Flow 1"))
        self.fr_2.setText(_translate("MainWindow", "Flow 2"))
        self.fr_3.setText(_translate("MainWindow", "Flow 3"))
        self.fr_4.setText(_translate("MainWindow", "Flow 4"))
        self.fr_5.setText(_translate("MainWindow", "Flow 5"))
        self.fr_6.setText(_translate("MainWindow", "Flow 6"))
        self.fr_7.setText(_translate("MainWindow", "Flow 7"))
        self.fr_8.setText(_translate("MainWindow", "Flow 8"))
        self.myTabs.setTabText(self.myTabs.indexOf(self.experimentTab), _translate("MainWindow", "Demo"))
        self.codeBrowser.setPlaceholderText(_translate("MainWindow", "Experiment source codes will be shown here..."))
        self.myTabs.setTabText(self.myTabs.indexOf(self.code), _translate("MainWindow", "Code"))
        self.myTabs.setTabText(self.myTabs.indexOf(self.remoteExptTab), _translate("MainWindow", "Experiment"))
