# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'loginDialog.ui'
#
# Created by: PyQt5 UI code generator 5.15.4
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(402, 199)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/myIcons/plus.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        Dialog.setWindowIcon(icon)
        Dialog.setStyleSheet("color: rgb(46, 52, 54);")
        self.gridLayout = QtWidgets.QGridLayout(Dialog)
        self.gridLayout.setObjectName("gridLayout")
        self.usernameBox = QtWidgets.QLineEdit(Dialog)
        font = QtGui.QFont()
        font.setPointSize(13)
        self.usernameBox.setFont(font)
        self.usernameBox.setMaxLength(100)
        self.usernameBox.setObjectName("usernameBox")
        self.gridLayout.addWidget(self.usernameBox, 2, 1, 1, 1)
        self.message_3 = QtWidgets.QLabel(Dialog)
        font = QtGui.QFont()
        font.setPointSize(13)
        self.message_3.setFont(font)
        self.message_3.setObjectName("message_3")
        self.gridLayout.addWidget(self.message_3, 2, 0, 1, 1)
        self.classroomBox = QtWidgets.QLineEdit(Dialog)
        font = QtGui.QFont()
        font.setPointSize(13)
        self.classroomBox.setFont(font)
        self.classroomBox.setMaxLength(100)
        self.classroomBox.setObjectName("classroomBox")
        self.gridLayout.addWidget(self.classroomBox, 6, 1, 1, 1)
        self.message_4 = QtWidgets.QLabel(Dialog)
        font = QtGui.QFont()
        font.setPointSize(13)
        self.message_4.setFont(font)
        self.message_4.setObjectName("message_4")
        self.gridLayout.addWidget(self.message_4, 6, 0, 1, 1)
        self.message = QtWidgets.QLabel(Dialog)
        font = QtGui.QFont()
        font.setPointSize(13)
        font.setItalic(True)
        self.message.setFont(font)
        self.message.setObjectName("message")
        self.gridLayout.addWidget(self.message, 0, 0, 1, 3)
        self.message_2 = QtWidgets.QLabel(Dialog)
        font = QtGui.QFont()
        font.setPointSize(13)
        self.message_2.setFont(font)
        self.message_2.setObjectName("message_2")
        self.gridLayout.addWidget(self.message_2, 3, 0, 1, 1)
        self.buttonBox = QtWidgets.QDialogButtonBox(Dialog)
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.gridLayout.addWidget(self.buttonBox, 7, 1, 1, 1)
        self.passwordBox = QtWidgets.QLineEdit(Dialog)
        font = QtGui.QFont()
        font.setPointSize(13)
        self.passwordBox.setFont(font)
        self.passwordBox.setMaxLength(100)
        self.passwordBox.setEchoMode(QtWidgets.QLineEdit.PasswordEchoOnEdit)
        self.passwordBox.setObjectName("passwordBox")
        self.gridLayout.addWidget(self.passwordBox, 3, 1, 1, 1)
        self.urlBox = QtWidgets.QLineEdit(Dialog)
        self.urlBox.setObjectName("urlBox")
        self.gridLayout.addWidget(self.urlBox, 1, 0, 1, 2)

        self.retranslateUi(Dialog)
        self.buttonBox.accepted.connect(Dialog.accept)
        self.buttonBox.rejected.connect(Dialog.reject)
        QtCore.QMetaObject.connectSlotsByName(Dialog)
        Dialog.setTabOrder(self.usernameBox, self.passwordBox)
        Dialog.setTabOrder(self.passwordBox, self.classroomBox)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "Login To ExpEYES Online"))
        self.usernameBox.setPlaceholderText(_translate("Dialog", "Enter Username..."))
        self.message_3.setText(_translate("Dialog", "Username"))
        self.classroomBox.setPlaceholderText(_translate("Dialog", "Classroom Name"))
        self.message_4.setText(_translate("Dialog", "Classroom"))
        self.message.setText(_translate("Dialog", "Enter Credentials"))
        self.message_2.setText(_translate("Dialog", "Password"))
        self.passwordBox.setPlaceholderText(_translate("Dialog", "Enter Password"))
from . import res_rc
