# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'joinDialog.ui'
#
# Created by: PyQt5 UI code generator 5.15.4
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(402, 83)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/myIcons/plus.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        Dialog.setWindowIcon(icon)
        Dialog.setStyleSheet("color: rgb(46, 52, 54);")
        self.gridLayout = QtWidgets.QGridLayout(Dialog)
        self.gridLayout.setObjectName("gridLayout")
        self.buttonBox = QtWidgets.QDialogButtonBox(Dialog)
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.gridLayout.addWidget(self.buttonBox, 3, 1, 1, 1)
        self.classroomBox = QtWidgets.QLineEdit(Dialog)
        font = QtGui.QFont()
        font.setPointSize(13)
        self.classroomBox.setFont(font)
        self.classroomBox.setMaxLength(100)
        self.classroomBox.setObjectName("classroomBox")
        self.gridLayout.addWidget(self.classroomBox, 2, 1, 1, 1)
        self.message_4 = QtWidgets.QLabel(Dialog)
        font = QtGui.QFont()
        font.setPointSize(13)
        self.message_4.setFont(font)
        self.message_4.setObjectName("message_4")
        self.gridLayout.addWidget(self.message_4, 2, 0, 1, 1)

        self.retranslateUi(Dialog)
        self.buttonBox.accepted.connect(Dialog.accept)
        self.buttonBox.rejected.connect(Dialog.reject)
        self.classroomBox.returnPressed.connect(Dialog.accept)
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "Join a Classroom"))
        self.classroomBox.setPlaceholderText(_translate("Dialog", "Classroom Name"))
        self.message_4.setText(_translate("Dialog", "Classroom"))
from . import res_rc
